@@ -3,7 +3,7 @@ from django.contrib import admin
 from django.contrib.auth.models import User
 
 # django-sendgrid
-from models import EmailTemplate
-
-
-admin.site.register(EmailTemplate)
+# from models import EmailTemplate
+# 
+# 
+# admin.site.register(EmailTemplate)
